Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrIPWhitelistConfigMissing = errors.New("no IPWhitelistConfig specified")
Functions ¶
This section is empty.
Types ¶
type IPWhitelistConfigReconciler ¶
type IPWhitelistConfigReconciler struct {
client.Client
Scheme *runtime.Scheme
IPWhitelistConfig string
RequeueInterval time.Duration
Log logr.Logger
}
IPWhitelistConfigReconciler reconciles a IPWhitelistConfig object
func (*IPWhitelistConfigReconciler) Reconcile ¶
func (r *IPWhitelistConfigReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state. For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.10.0/pkg/reconcile Interesting thing to note here is that this Reconcile is triggered for Ingress Objects and not IPWhitelistConfig
func (*IPWhitelistConfigReconciler) SetupWithManager ¶
func (r *IPWhitelistConfigReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type ProviderString ¶
type ProviderString string
func (ProviderString) String ¶
func (p ProviderString) String() string
Click to show internal directories.
Click to hide internal directories.